@@ -27,6 +27,7 @@
 
 #include <arvgcfloat.h>
 #include <arvgcfeaturenode.h>
+#include <arvgcdefaultsprivate.h>
 #include <arvgc.h>
 #include <arvmisc.h>
 
@@ -112,25 +113,98 @@ arv_gc_float_get_inc (ArvGcFloat *gc_float, GError **error)
 	return 1;
 }
 
+/**
+ * arv_gc_float_get_representation:
+ * @gc_float: a #ArvGcFloat
+ *
+ * Get number representation format.
+ *
+ * Returns: Number representation format as #ArvGcRepresentation.
+ */
+
+ArvGcRepresentation
+arv_gc_float_get_representation (ArvGcFloat *gc_float)
+{
+	ArvGcFloatInterface *float_interface;
+
+	g_return_val_if_fail (ARV_IS_GC_FLOAT (gc_float), ARV_GC_REPRESENTATION_UNDEFINED);
+
+	float_interface = ARV_GC_FLOAT_GET_IFACE (gc_float);
+
+	if (float_interface->get_representation != NULL)
+		return float_interface->get_representation (gc_float);
+
+	return ARV_GC_REPRESENTATION_UNDEFINED;
+}
+
 const char *
-arv_gc_float_get_unit	(ArvGcFloat *gc_float, GError **error)
+arv_gc_float_get_unit	(ArvGcFloat *gc_float)
 {
 	ArvGcFloatInterface *float_interface;
 
 	g_return_val_if_fail (ARV_IS_GC_FLOAT (gc_float), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	float_interface = ARV_GC_FLOAT_GET_IFACE (gc_float);
 
 	if (float_interface->get_unit != NULL)
-		return float_interface->get_unit (gc_float, error);
-
-	g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_PROPERTY_NOT_DEFINED, "<Unit> node not found for '%s'",
-		     arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (gc_float)));
+		return float_interface->get_unit (gc_float);
 
 	return NULL;
 }
 
+/**
+ * arv_gc_float_get_display_notation:
+ * @gc_float: a #ArvGcFloat
+ *
+ * Get number display notation.
+ *
+ * Returns: Number display notation as #ArvGcDisplayNotation.
+ *
+ * Since: 0.8.0
+ */
+
+ArvGcDisplayNotation
+arv_gc_float_get_display_notation (ArvGcFloat *gc_float)
+{
+	ArvGcFloatInterface *float_interface;
+
+	g_return_val_if_fail (ARV_IS_GC_FLOAT (gc_float), ARV_GC_DISPLAY_NOTATION_DEFAULT);
+
+	float_interface = ARV_GC_FLOAT_GET_IFACE (gc_float);
+
+	if (float_interface->get_display_notation != NULL)
+		return float_interface->get_display_notation (gc_float);
+
+	return ARV_GC_DISPLAY_NOTATION_DEFAULT;
+}
+
+/**
+ * arv_gc_float_get_display_precision:
+ * @gc_float: a #ArvGcFloat
+ *
+ * Gets number of digits to show in user interface. This number should always be positive and represent
+ * total number of digits on left and right side of decimal.
+ *
+ * Returns: Number of digits to show.
+ *
+ * Since: 0.8.0
+ */
+
+gint64
+arv_gc_float_get_display_precision (ArvGcFloat *gc_float)
+{
+	ArvGcFloatInterface *float_interface;
+
+	g_return_val_if_fail (ARV_IS_GC_FLOAT (gc_float), ARV_GC_DISPLAY_PRECISION_DEFAULT);
+
+	float_interface = ARV_GC_FLOAT_GET_IFACE (gc_float);
+
+	if (float_interface->get_display_precision != NULL)
+		return float_interface->get_display_precision (gc_float);
+
+	return ARV_GC_DISPLAY_PRECISION_DEFAULT;
+}
+
 void arv_gc_float_impose_min (ArvGcFloat *gc_float, double minimum, GError **error)
 {
 	ArvGcFloatInterface *float_interface;
