@@ -38,7 +38,7 @@
 #include <arvgcport.h>
 #include <arvgc.h>
 #include <arvmisc.h>
-#include <arvdebug.h>
+#include <arvdebugprivate.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -306,11 +306,14 @@ _get_cache (ArvGcRegisterNode *self, gint64 *address, gint64 *length, GError **e
 }
 
 static ArvGcAccessMode
-_get_access_mode (ArvGcRegisterNode *self)
+arv_gc_register_node_get_access_mode (ArvGcFeatureNode *gc_feature_node)
 {
-	ArvGcRegisterNodePrivate *priv = arv_gc_register_node_get_instance_private (ARV_GC_REGISTER_NODE (self));
+	ArvGcRegisterNodePrivate *priv = arv_gc_register_node_get_instance_private (ARV_GC_REGISTER_NODE (gc_feature_node));
 
-	return arv_gc_property_node_get_access_mode(priv->access_mode, ARV_GC_ACCESS_MODE_RW);
+	if (priv->access_mode == NULL)
+		return ARV_GC_ACCESS_MODE_RO;
+
+	return arv_gc_property_node_get_access_mode (priv->access_mode, ARV_GC_ACCESS_MODE_RO);
 }
 
 static void
@@ -440,11 +443,13 @@ arv_gc_register_node_class_init (ArvGcRegisterNodeClass *this_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (this_class);
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
+	ArvGcFeatureNodeClass *gc_feature_node_class = ARV_GC_FEATURE_NODE_CLASS (this_class);
 
 	object_class->finalize = arv_gc_register_node_finalize;
 	dom_node_class->get_node_name = arv_gc_register_node_get_node_name;
 	dom_node_class->post_new_child = arv_gc_register_node_post_new_child;
 	dom_node_class->pre_remove_child = arv_gc_register_node_pre_remove_child;
+	gc_feature_node_class->get_access_mode = arv_gc_register_node_get_access_mode;
 
 	this_class->default_cachable = ARV_GC_CACHABLE_WRITE_THROUGH;
 }
@@ -484,7 +489,7 @@ arv_gc_register_node_get (ArvGcRegister *gc_register, void *buffer, guint64 leng
 	} else
 		memcpy (buffer, cache, length);
 
-	arv_log_genicam ("[GcRegisterNode::get] 0x%Lx,%Ld", address, length);
+	arv_log_genicam ("[GcRegisterNode::get] 0x%" G_GINT64_MODIFIER "x,%" G_GUINT64_FORMAT, address, length);
 }
 
 static void
@@ -521,7 +526,7 @@ arv_gc_register_node_set (ArvGcRegister *gc_register, const void *buffer, guint6
 		return;
 	}
 
-	arv_log_genicam ("[GcRegisterNode::set] 0x%Lx,%Ld", address, length);
+	arv_log_genicam ("[GcRegisterNode::set] 0x%" G_GINT64_MODIFIER "x,%" G_GUINT64_FORMAT, address, length);
 }
 
 static guint64
@@ -590,7 +595,7 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node,
 
 		arv_log_genicam ("[GcRegisterNode::_get_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
 				 register_lsb, register_msb, lsb, msb);
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] value = 0x%08Lx", value);
+		arv_log_genicam ("[GcRegisterNode::_get_integer_value] value = 0x%08" G_GINT64_MODIFIER "x", value);
 
 		if (msb - lsb < 63)
 			mask = ((((guint64) 1) << (msb - lsb + 1)) - 1) << lsb;
@@ -605,7 +610,7 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node,
 			value |= G_MAXUINT64 ^ (mask >> lsb);
 		}
 
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] mask  = 0x%08Lx", mask);
+		arv_log_genicam ("[GcRegisterNode::_get_integer_value] mask  = 0x%08" G_GINT64_MODIFIER "x", mask);
 	} else {
 		if (length < 8 &&
 		    ((value & (((guint64) 1) << (length * 8 - 1))) != 0) &&
@@ -613,7 +618,7 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node,
 			value |= G_MAXUINT64 ^ ((((guint64) 1) << (length * 8)) - 1);
 	}
 
-	arv_log_genicam ("[GcRegisterNode::_get_integer_value] address = 0x%Lx, value = 0x%Lx",
+	arv_log_genicam ("[GcRegisterNode::_get_integer_value] address = 0x%" G_GINT64_MODIFIER "x, value = 0x%" G_GINT64_MODIFIER "x",
 			 _get_address (gc_register_node, NULL), value);
 
 	return value;
@@ -662,7 +667,7 @@ _set_integer_value (ArvGcRegisterNode *gc_register_node,
 		gint64 current_value;
 		guint64 mask;
 
-		if (ARV_GC_ACCESS_MODE_WO != _get_access_mode(gc_register_node)) {
+		if (ARV_GC_ACCESS_MODE_WO != arv_gc_register_node_get_access_mode(ARV_GC_FEATURE_NODE(gc_register_node))) {
 			_read_from_port (gc_register_node, address, length, cache, cachable, &local_error);
 			if (local_error != NULL) {
 				g_propagate_error (error, local_error);
@@ -683,7 +688,7 @@ _set_integer_value (ArvGcRegisterNode *gc_register_node,
 
 		arv_log_genicam ("[GcRegisterNode::_set_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
 				 register_lsb, register_msb, lsb, msb);
-		arv_log_genicam ("[GcRegisterNode::_set_integer_value] value = 0x%08Lx", value);
+		arv_log_genicam ("[GcRegisterNode::_set_integer_value] value = 0x%08" G_GINT64_MODIFIER "x", value);
 
 		if (msb - lsb < 63)
 			mask = ((((guint64) 1) << (msb - lsb + 1)) - 1) << lsb;
@@ -692,10 +697,10 @@ _set_integer_value (ArvGcRegisterNode *gc_register_node,
 
 		value = ((value << lsb) & mask) | (current_value & ~mask);
 
-		arv_log_genicam ("[GcRegisterNode::_set_integer_value] mask  = 0x%08Lx", mask);
+		arv_log_genicam ("[GcRegisterNode::_set_integer_value] mask  = 0x%08" G_GINT64_MODIFIER "x", mask);
 	}
 
-	arv_log_genicam ("[GcRegisterNode::_set_integer_value] address = 0x%Lx, value = 0x%Lx",
+	arv_log_genicam ("[GcRegisterNode::_set_integer_value] address = 0x%" G_GINT64_MODIFIER "x, value = 0x%" G_GINT64_MODIFIER "x",
 			 _get_address (gc_register_node, NULL), value);
 
 	arv_copy_memory_with_endianness (cache, length, endianness,
