@@ -21,7 +21,7 @@
  */
 
 #include <arvmiscprivate.h>
-#include <arvdebug.h>
+#include <arvdebugprivate.h>
 #include <string.h>
 #include <math.h>
 #include <stdio.h>
@@ -507,8 +507,8 @@ arv_decompress (void *input_buffer, size_t input_size, size_t *output_size)
 		stream.avail_in = MIN (input_size, ARV_DECOMPRESS_CHUNK);
 		stream.next_in = input_buffer;
 
-		arv_debug_misc ("[Decompress] Input ptr = 0x%x - Chunk size = %d - %c",
-				stream.next_in, stream.avail_in, *stream.next_in);
+		arv_debug_misc ("[Decompress] Input ptr = 0x%p - Chunk size = %d - %c",
+				(void *) stream.next_in, stream.avail_in, *stream.next_in);
 
 		input_size -= stream.avail_in;
 		input_buffer = ((char *) input_buffer) + stream.avail_in;
